Learn R Programming

evitaicossa (version 0.0-1)

aaa-class: Class "aaa"

Description

Class aaa is for elements of the free antiassociative algebra

Arguments

Objects from the Class

Objects can be created by calls of the form new("aaa", ...).

Slots

single_indeterminate_name1:

Object of class "character"

single_indeterminate_coeff:

Object of class "numeric"

double_indeterminate_name1:

Object of class "character"

double_indeterminate_name2:

Object of class "character"

double_indeterminate_coeff:

Object of class "numeric"

triple_indeterminate_name1:

Object of class "character"

triple_indeterminate_name2:

Object of class "character"

triple_indeterminate_name3:

Object of class "character"

triple_indeterminate_coeff:

Object of class "numeric"

Author

Robin K. S. Hankin

Examples

Run this code
showClass("aaa")

Run the code above in your browser using DataLab