Learn R Programming

evitaicossa (version 0.0-1)

evitaicossa-package: tools:::Rd_package_title("evitaicossa")

Description

tools:::Rd_package_description("evitaicossa")

Arguments

Author

tools:::Rd_package_author("evitaicossa")

Maintainer: tools:::Rd_package_maintainer("evitaicossa")

Details

The DESCRIPTION file: tools:::Rd_package_DESCRIPTION("evitaicossa") tools:::Rd_package_indices("evitaicossa")

Functionality to work with the free antiassociative algebra in R. The hex sticker features an image taken from hoffnung1959;textualevitaicossa in which musical concepts [pizzicato, crescendo, etc] are given whimsical visual form. The character on the hex sticker is captioned “A Discord”: Hoffnung's interpretation of the musical concept of dissonance. In the book, the preceding image was a “chord”, evoking harmony. The discord, on the other hand, embodies--for me at least--antiassociativity: everything is wrong, wrong, wrong.

References

See Also

aaa

Examples

Run this code
x <- raaa()
x
y <- raaa()

x+y
x*y

Run the code above in your browser using DataLab